Zwift Workouts Parser 
---------------------

Want to try a workout of some specific plan on Zwift but don't want to start the plan? Use this utility to parse any desired plan or workout straight from the https://whatsonzwift.com. 

Just feed it with an URL and it will export everything it can into .zwo files which you can import into Zwift and try them out. 
